==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/creatures/dialogs_cs.lua <==

dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")
dialogStr("Podívej se na všechny ty kraby...")


dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")
dialogStr("Spí tu tisíce let... ponořeni ve věčnou nečinnost...")


dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")
dialogStr("...a vláda to tají.")


dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")
dialogStr("...nic je neprobudí z jejich spánku...")


dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")
dialogStr("Pokud ovšem neaktivujeme tu chobotnici.")


dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")
dialogStr("Podívej, všechno je tu tak mrtvé a nehybné.")


dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")
dialogStr("Vždyť ty sasanky se celkem hýbou.")


dialogId("kor-v-treba", "font_big", "Maybe they`re in the throes of death.")
dialogStr("Třeba jsou to smrtelné křeče.")


dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")
dialogStr("Shledávám v tom jistou symboliku.")


dialogId("kor-v-bermudy", "font_big", "That`s interesting. This type of coral normally grows only in the Bermuda Triangle.")
dialogStr("To je zajímavé, tento druh korálu přece roste jen v bermudském trojúhelníku.")


dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")
dialogStr("Víš o tom, že některé druhy korálů jsou skoro tak inteligentní jako ryby?")


dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")
dialogStr("Dej si pozor, většina korálů je jedovatých.")


dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a 'coral-soul`?")
dialogStr("Co myslíš, mají korály duši?")


dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")
dialogStr("Nemáš pocit, že nás ty korály pozorují?")


dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")
dialogStr("Zajímalo by mě, proč mají ty korály tak bizarní tvary.")


dialogId("kor-v-juchacka", "font_big", "That was some number, wasn`t it?")
dialogStr("To byla juchačka, co?")


dialogId("kor-m-hraje", "font_small", "Yeah, he`s a great player.")
dialogStr("No, hraje celkem obstojně.")


dialogId("kor-v-odvaz", "font_big", "That`s cool. What if we pushed him again?")
dialogStr("Docela odvaz, co kdybychom do ní ještě šťouchli?")


dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")
dialogStr("Všiml sis, co dělali ti krabi?")


dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")
dialogStr("A viděla jsi, jak trsaly ty sasanky?")


dialogId("kor-m-tovis", "font_small", "Well, you know, it`s not all that much fun down here at the bottom of the ocean.")
dialogStr("To víš, moc radosti si zde v hlubině asi neužijou.")


dialogId("kor-v-vali", "font_big", "He`s good, isn`t he?")
dialogStr("Ta ale válí, co?")


dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")
dialogStr("Na chobotnici to celkem ujde...")


dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")
dialogStr("Myslíš, že umí taky nějakou jinou melodii?")


dialogId("kor-m-neprehani", "font_small", "Don`t you think we`ve had enough already?")
dialogStr("Nezdá se ti, že už to přehání?")


dialogId("kor-m-lezekrkem", "font_small", "I`m getting sick of it...")
dialogStr("Už mi to leze krkem...")


dialogId("kor-v-lezekrkem", "font_big", "I`m sick and tired of it...")
dialogStr("Už mi to leze krkem...")


dialogId("kor-v-kostice", "font_big", "I`m fed up to the gills with this.")
dialogStr("Už toho mám plný kostice.")


dialogId("kor-v-odsud", "font_big", "I can`t budge this from where I am. I`d have to try to move it from the left side.")
dialogStr("Odsud s tím nepohnu, potřeboval bych se k tomu dostat zleva.")


dialogId("kor-m-budesmuset", "font_small", "Well you`ll have to go that way through those anemones.")
dialogStr("To ale budeš muset projet támhle mezi těma sasankama.")


dialogId("kor-m-neniono", "font_small", "That`s not what I had in mind...")
dialogStr("To není ono...")


dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")
dialogStr("Tu díru by to chtělo předem nějak ucpat.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/creatures/dialogs_cs.lua <==

dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")
dialogStr("Podívej se na všechny ty kraby...")


dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")
dialogStr("Spí tu tisíce let... ponořeni ve věčnou nečinnost...")


dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")
dialogStr("...a vláda to tají.")


dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")
dialogStr("...nic je neprobudí z jejich spánku...")


dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")
dialogStr("Pokud ovšem neaktivujeme tu chobotnici.")


dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")
dialogStr("Podívej, všechno je tu tak mrtvé a nehybné.")


dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")
dialogStr("Vždyť ty sasanky se celkem hýbou.")


dialogId("kor-v-treba", "font_big", "Maybe they’re in the throes of death.")
dialogStr("Třeba jsou to smrtelné křeče.")


dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")
dialogStr("Shledávám v tom jistou symboliku.")


dialogId("kor-v-bermudy", "font_big", "That’s interesting. This type of coral normally grows only in the Bermuda Triangle.")
dialogStr("To je zajímavé, tento druh korálu přece roste jen v bermudském trojúhelníku.")


dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")
dialogStr("Víš o tom, že některé druhy korálů jsou skoro tak inteligentní jako ryby?")


dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")
dialogStr("Dej si pozor, většina korálů je jedovatých.")


dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a 'coral-soul’?")
dialogStr("Co myslíš, mají korály duši?")


dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")
dialogStr("Nemáš pocit, že nás ty korály pozorují?")


dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")
dialogStr("Zajímalo by mě, proč mají ty korály tak bizarní tvary.")


dialogId("kor-v-juchacka", "font_big", "That was some number, wasn’t it?")
dialogStr("To byla juchačka, co?")


dialogId("kor-m-hraje", "font_small", "Yeah, he’s a great player.")
dialogStr("No, hraje celkem obstojně.")


dialogId("kor-v-odvaz", "font_big", "That’s cool. What if we pushed him again?")
dialogStr("Docela odvaz, co kdybychom do ní ještě šťouchli?")


dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")
dialogStr("Všiml sis, co dělali ti krabi?")


dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")
dialogStr("A viděla jsi, jak trsaly ty sasanky?")


dialogId("kor-m-tovis", "font_small", "Well, you know, it’s not all that much fun down here at the bottom of the ocean.")
dialogStr("To víš, moc radosti si zde v hlubině asi neužijou.")


dialogId("kor-v-vali", "font_big", "He’s good, isn’t he?")
dialogStr("Ta ale válí, co?")


dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")
dialogStr("Na chobotnici to celkem ujde...")


dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")
dialogStr("Myslíš, že umí taky nějakou jinou melodii?")


dialogId("kor-m-neprehani", "font_small", "Don’t you think we’ve had enough already?")
dialogStr("Nezdá se ti, že už to přehání?")


dialogId("kor-m-lezekrkem", "font_small", "I’m getting sick of it...")
dialogStr("Už mi to leze krkem...")


dialogId("kor-v-lezekrkem", "font_big", "I’m sick and tired of it...")
dialogStr("Už mi to leze krkem...")


dialogId("kor-v-kostice", "font_big", "I’m fed up to the gills with this.")
dialogStr("Už toho mám plný kostice.")


dialogId("kor-v-odsud", "font_big", "I can’t budge this from where I am. I’d have to try to move it from the left side.")
dialogStr("Odsud s tím nepohnu, potřeboval bych se k tomu dostat zleva.")


dialogId("kor-m-budesmuset", "font_small", "Well you’ll have to go that way through those anemones.")
dialogStr("To ale budeš muset projet támhle mezi těma sasankama.")


dialogId("kor-m-neniono", "font_small", "That’s not what I had in mind...")
dialogStr("To není ono...")


dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")
dialogStr("Tu díru by to chtělo předem nějak ucpat.")
